==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ro/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confirmarea activelor șterse în bloc',
  'bulk_delete_help'	=> 'Consultați mai jos activele pentru ștergerea în bloc. Odată șterse, aceste active pot fi restaurate, dar nu vor mai fi asociate cu utilizatorii cărora li se alocă în prezent.',
  'bulk_delete_warn'	=> 'Sunteți pe cale să ștergeți: active_count assets.',
	'bulk_update'		=> 'Actualizarea activelor în bloc',
	'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai multe elemente. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
	'bulk_update_warn'	=> 'Sunteți pe punctul de a edita proprietățile: active_count assets.',
    'checkedout_to'		=> 'Alocat la',
    'checkout_date'		=> 'Verifica data',
    'checkin_date'		=> 'Verificați data',
    'checkout_to'		=> 'De alocat la',
    'cost'				=> 'Cost achizitie',
    'create'			=> 'Creeaza activ',
    'date'				=> 'Data achizitie',
    'depreciation'	    => 'Depreciere',
    'depreciates_on'	=> 'Depreciere la',
    'default_location'	=> 'Locatie implicita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Rata EOL',
    'expected_checkin'  => 'Data de așteptare așteptată',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Depreciere completa',
    'help_checkout'		=> 'Dacă doriți să alocați imediat acest activ, selectați "Gata de implementat" din lista de stare de mai sus.',
    'mac_address'		=> 'Adresa mac',
    'manufacturer'		=> 'Producator',
    'model'				=> 'Model',
    'months'			=> 'Luni',
    'name'				=> 'Nume activ',
    'notes'				=> 'Note',
    'order'				=> 'Numar ordine',
    'qr'				=> 'Cod QR',
    'requestable'		=> 'Utilizatorii pot cere acest activ',
    'select_statustype'	=> 'Selecteaza tip status',
    'serial'			=> 'Serie',
    'status'			=> 'Stare',
    'tag'				=> 'Eticheta activ',
    'update'			=> 'Actualizeaza activ',
    'warranty'			=> 'Garantie',
		'warranty_expires'		=> 'Garanția expiră',
    'years'				=> 'Ani',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ro/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmarea activelor șterse în bloc',
  'bulk_delete_help'	=> 'Consultați mai jos activele pentru ștergerea în bloc. Odată șterse, aceste active pot fi restaurate, dar nu vor mai fi asociate cu utilizatorii cărora li se alocă în prezent.',
  'bulk_delete_warn'	=> 'Sunteți pe cale să ștergeți: active_count assets.',
    'bulk_update'		=> 'Actualizarea activelor în bloc',
    'bulk_update_help'	=> 'Acest formular vă permite să actualizați simultan mai multe elemente. Completați câmpurile pe care trebuie să le schimbați. Toate câmpurile rămase necompletate vor rămâne neschimbate.',
    'bulk_update_warn'	=> 'Sunteți pe punctul de a edita proprietățile: active_count assets.',
    'checkedout_to'		=> 'Alocat la',
    'checkout_date'		=> 'Verifica data',
    'checkin_date'		=> 'Verificați data',
    'checkout_to'		=> 'De alocat la',
    'cost'				=> 'Cost achizitie',
    'create'			=> 'Creeaza activ',
    'date'				=> 'Data achizitie',
    'depreciation'	    => 'Depreciere',
    'depreciates_on'	=> 'Depreciere la',
    'default_location'	=> 'Locatie implicita',
    'eol_date'			=> 'Data EOL',
    'eol_rate'			=> 'Rata EOL',
    'expected_checkin'  => 'Data de așteptare așteptată',
    'expires'			=> 'Expira',
    'fully_depreciated'	=> 'Depreciere completa',
    'help_checkout'		=> 'Dacă doriți să alocați imediat acest activ, selectați "Gata de implementat" din lista de stare de mai sus.',
    'mac_address'		=> 'Adresa mac',
    'manufacturer'		=> 'Producator',
    'model'				=> 'Model',
    'months'			=> 'Luni',
    'name'				=> 'Nume activ',
    'notes'				=> 'Note',
    'order'				=> 'Numar ordine',
    'qr'				=> 'Cod QR',
    'requestable'		=> 'Utilizatorii pot cere acest activ',
    'select_statustype'	=> 'Selecteaza tip status',
    'serial'			=> 'Serie',
    'status'			=> 'Stare',
    'tag'				=> 'Eticheta activ',
    'update'			=> 'Actualizeaza activ',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Garanția expiră',
    'years'				=> 'Ani',
    'asset_location' => 'Actualizați locația activului',
    'asset_location_update_default_current' => 'Actualizați locația implicită ȘI locația curentă',
    'asset_location_update_default' => 'Actualizați doar locația implicită',
    'asset_not_deployable' => 'Activul este indisponibil și nu poate fi eliberat.',
    'asset_deployable' => 'Activul e disponibil și poate fi eliberat.',
    'processing_spinner' => 'În curs de procesare...',
];
